Package: metadat
Version: 1.6-0
Date: 2026-04-29
Title: Meta-Analysis Datasets
Authors@R: c(
  person(given = "Wolfgang", family = "Viechtbauer",
  role = c("aut","cre"), email = "wvb@metafor-project.org",
  comment = c(ORCID = "0000-0003-3463-4063")),
  person(given = "Thomas", family="White",
  role="aut", email = "thomas.white@sydney.edu.au",
  comment = c(ORCID = "0000-0002-3976-1734")),
  person(given = "Daniel", family="Noble",
  role="aut", email = "daniel.noble@anu.edu.au",
  comment = c(ORCID = "0000-0001-9460-8743")),
  person(given = "Alistair", family="Senior",
  role="aut", email = "alistair.senior@sydney.edu.au",
  comment = c(ORCID = "0000-0001-9805-7280")),
  person(given = "W. Kyle", family="Hamilton",
  role="aut", email = "whamilton@ucmerced.edu",
  comment = c(ORCID = "0000-0002-8642-7990")),
  person(given = "Guido", family = "Schwarzer",
  role = "dtc", email = "guido.schwarzer@uniklinik-freiburg.de",
  comment = c(ORCID = "0000-0001-6214-9087")),
  person(given = "Christian", family = "Röver",
  role = "dtc", email = "christian.roever@med.uni-goettingen.de",
  comment = c(ORCID = "0000-0002-6911-698X")))
Depends: R (>= 4.0.0)
Imports: utils, tools, mathjaxr
Suggests: metafor, numDeriv, BiasedUrn, dfoptim, igraph, ape, testthat,
        digest, lme4, clubSandwich, meta, netmeta, mvtnorm, gridExtra,
        rms, bayesmeta, ellipse, metasens, mada
Description: A collection of meta-analysis datasets for teaching purposes, illustrating/testing meta-analytic methods, and validating published analyses.
License: GPL (>= 2)
ByteCompile: TRUE
LazyData: TRUE
Encoding: UTF-8
RdMacros: mathjaxr
BuildManual: TRUE
URL: https://github.com/wviechtb/metadat,
        https://wviechtb.github.io/metadat/
BugReports: https://github.com/wviechtb/metadat/issues
NeedsCompilation: no
Packaged: 2026-04-29 13:52:03 UTC; wviechtb
Author: Wolfgang Viechtbauer [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3463-4063>),
  Thomas White [aut] (ORCID: <https://orcid.org/0000-0002-3976-1734>),
  Daniel Noble [aut] (ORCID: <https://orcid.org/0000-0001-9460-8743>),
  Alistair Senior [aut] (ORCID: <https://orcid.org/0000-0001-9805-7280>),
  W. Kyle Hamilton [aut] (ORCID: <https://orcid.org/0000-0002-8642-7990>),
  Guido Schwarzer [dtc] (ORCID: <https://orcid.org/0000-0001-6214-9087>),
  Christian Röver [dtc] (ORCID: <https://orcid.org/0000-0002-6911-698X>)
Maintainer: Wolfgang Viechtbauer <wvb@metafor-project.org>
Repository: CRAN
Date/Publication: 2026-04-29 15:10:14 UTC
Built: R 4.6.0; ; 2026-04-29 15:57:20 UTC; unix
